#ifndef REDUCEDROWECHELONFORM_HEADER
#define REDUCEDROWECHELONFORM_HEADER

#include <stddef.h>

void ReducedRowEchelonForm(
  double *mat,
  const size_t nrows,
  const size_t ncolumns
);

#endif

